SQLAlchemy 0.3 Documentation - module sqlalchemy.ext.sessioncontext

# SQLAlchemy 0.3 Documentation

Multiple Pages | One Page
Version: 0.3.10 Last Updated: 07/20/07 17:20:04

### module sqlalchemy.ext.sessioncontext

### class SessionContext(object)

A simple wrapper for `ScopedRegistry` that provides a current property which can be used to get, set, or remove the session in the current scope.

By default this object provides thread-local scoping, which is the default scope provided by sqlalchemy.util.ScopedRegistry.

Usage:

    engine = create_engine(...)
    def session_factory():
        return Session(bind_to=engine)
    context = SessionContext(session_factory)

    s = context.current # get thread-local session
    context.current = Session(bind_to=other_engine) # set current session
    del context.current # discard the thread-local session (a new one will
                        # be created on the next call to context.current)

def __init__(self, session_factory, scopefunc=None)
current = property()

Property used to get/set/del the session in the current scope.

def del_current(self)
def get_current(self)
mapper_extension = property()

Get a mapper extension that implements get_session using this context.

def set_current(self, session)
back to section top

### class SessionContextExt(MapperExtension)

A mapper extension that provides sessions to a mapper using `SessionContext`.

def __init__(self, context)
def get_session(self)
back to section top